@@ -29,9 +29,9 @@
 #include <QDebug>
 #include <QStandardPaths>
 #include <Plasma/Package>
-#include <Kross/Action>
-#include <Kross/Interpreter>
-#include <Kross/Manager>
+#include <Kross/Core/Action>
+#include <Kross/Core/Interpreter>
+#include <Kross/Core/Manager>
 
 #include <Plasma/PluginLoader>
 
@@ -256,30 +256,30 @@ bool StaticDateWrapper::isValid (int year, int month, int day)
 
 QString StaticDateWrapper::longDayName (int weekday)
 {
-    return QDate::longDayName(weekday);
+    return QLocale::system().dayName(weekday, QLocale::LongFormat);
 }
 
 QString StaticDateWrapper::longMonthName (int month)
 {
-    return QDate::longMonthName(month);
+    return QLocale::system().monthName(month, QLocale::LongFormat);
 }
 
 QString StaticDateWrapper::shortDayName (int weekday)
 {
-    return QDate::shortDayName(weekday);
+    return QLocale::system().dayName(weekday, QLocale::ShortFormat);
 }
 
 QString StaticDateWrapper::shortMonthName (int month)
 {
-    return QDate::shortMonthName(month);
+    return QLocale::system().monthName(month, QLocale::ShortFormat);
 }
 
 ComicProviderWrapper::ComicProviderWrapper(ComicProviderKross *parent)
     : QObject(parent),
-      mAction(0),
+      mAction(nullptr),
       mProvider(parent),
-      mKrossImage(0),
-      mPackage(0),
+      mKrossImage(nullptr),
+      mPackage(nullptr),
       mRequests(0),
       mIdentifierSpecified(false),
       mIsLeftToRight(true),
@@ -309,7 +309,7 @@ void ComicProviderWrapper::init()
             // https://techbase.kde.org/Development/Tutorials/Plasma4/ComicPlugin#Package_Structure has main.es defined as mainscript.
             // Also Package::isValid() fails because the mainscript search fails to find the "main" file from mainscript.
 
-            QString mainscript = mPackage->filePath("scripts") + "/" + "main";
+            QString mainscript = mPackage->filePath("scripts") + QLatin1String("/main");
             QFileInfo info(mainscript);
             for (int i = 0; i < extensions().count() && !info.exists(); ++i) {
                     info.setFile(mainscript + extensions().value(i));
@@ -480,12 +480,12 @@ void ComicProviderWrapper::setTopToBottom(bool ttb)
 
 QString ComicProviderWrapper::textCodec() const
 {
-    return QString::fromAscii(mTextCodec);
+    return QString::fromLatin1(mTextCodec);
 }
 
 void ComicProviderWrapper::setTextCodec(const QString &textCodec)
 {
-    mTextCodec = textCodec.toAscii();
+    mTextCodec = textCodec.toLatin1();
 }
 
 QString ComicProviderWrapper::comicAuthor() const
@@ -723,7 +723,7 @@ void ComicProviderWrapper::pageRetrieved(int id, const QByteArray &data)
             finished();
         }
     } else {
-        QTextCodec *codec = 0;
+        QTextCodec *codec = nullptr;
         if (!mTextCodec.isEmpty()) {
             codec = QTextCodec::codecForName(mTextCodec);
         }
@@ -756,16 +756,16 @@ void ComicProviderWrapper::redirected(int id, const QUrl &newUrl)
 
 void ComicProviderWrapper::finished() const
 {
-    qDebug() << QString(QLatin1String("Author")).leftJustified(22, QLatin1Char('.')) << comicAuthor();
-    qDebug() << QString(QLatin1String("Website URL")).leftJustified(22, QLatin1Char('.')) << mWebsiteUrl;
-    qDebug() << QString(QLatin1String("Shop URL")).leftJustified(22, QLatin1Char('.')) << mShopUrl;
-    qDebug() << QString(QLatin1String("Title")).leftJustified(22, QLatin1Char('.')) << mTitle;
-    qDebug() << QString(QLatin1String("Additional Text")).leftJustified(22, QLatin1Char('.')) << mAdditionalText;
-    qDebug() << QString(QLatin1String("Identifier")).leftJustified(22, QLatin1Char('.')) << mIdentifier;
-    qDebug() << QString(QLatin1String("First Identifier")).leftJustified(22, QLatin1Char('.')) << mFirstIdentifier;
-    qDebug() << QString(QLatin1String("Last Identifier")).leftJustified(22, QLatin1Char('.')) << mLastIdentifier;
-    qDebug() << QString(QLatin1String("Next Identifier")).leftJustified(22, QLatin1Char('.')) << mNextIdentifier;
-    qDebug() << QString(QLatin1String("Previous Identifier")).leftJustified(22, QLatin1Char('.')) << mPreviousIdentifier;
+    qDebug() << QString::fromLatin1("Author").leftJustified(22, QLatin1Char('.')) << comicAuthor();
+    qDebug() << QString::fromLatin1("Website URL").leftJustified(22, QLatin1Char('.')) << mWebsiteUrl;
+    qDebug() << QString::fromLatin1("Shop URL").leftJustified(22, QLatin1Char('.')) << mShopUrl;
+    qDebug() << QString::fromLatin1("Title").leftJustified(22, QLatin1Char('.')) << mTitle;
+    qDebug() << QString::fromLatin1("Additional Text").leftJustified(22, QLatin1Char('.')) << mAdditionalText;
+    qDebug() << QString::fromLatin1("Identifier").leftJustified(22, QLatin1Char('.')) << mIdentifier;
+    qDebug() << QString::fromLatin1("First Identifier").leftJustified(22, QLatin1Char('.')) << mFirstIdentifier;
+    qDebug() << QString::fromLatin1("Last Identifier").leftJustified(22, QLatin1Char('.')) << mLastIdentifier;
+    qDebug() << QString::fromLatin1("Next Identifier").leftJustified(22, QLatin1Char('.')) << mNextIdentifier;
+    qDebug() << QString::fromLatin1("Previous Identifier").leftJustified(22, QLatin1Char('.')) << mPreviousIdentifier;
     emit mProvider->finished(mProvider);
 }
 
